@@ -20,7 +20,7 @@ An example session demonstrating the use of this module:
 
 """
 
-# Copyright 2009 - 2010 Harri Pitkänen (hatapitk@iki.fi)
+# Copyright 2009 - 2011 Harri Pitkänen (hatapitk@iki.fi)
 # This library requires Python version 2.5 or newer.
 
 # This program is free software; you can redistribute it and/or modify
@@ -156,6 +156,14 @@ def _boolToInt(bool):
 	else:
 		return 0
 
+def _anyStringToUtf8(anyString):
+	if not anyString:
+		return None
+	if type(anyString) == unicode:
+		return anyString.encode("UTF-8")
+	else:
+		return anyString
+
 class Voikko(object):
 	def __getLib():
 		if os.name == 'nt':
@@ -245,7 +253,7 @@ class Voikko(object):
 		self.__lib.voikkoSetIntegerOption.restype = c_int
 		
 		error = c_char_p()
-		self.__handle = self.__lib.voikkoInit(byref(error), language, path)
+		self.__handle = self.__lib.voikkoInit(byref(error), _anyStringToUtf8(language), _anyStringToUtf8(path))
 		if error.value != None:
 			self.__handle = 0
 			raise VoikkoException(u"Initialization of Voikko failed: " + unicode(error.value, "UTF-8"))
@@ -259,6 +267,9 @@ class Voikko(object):
 		if result == 0:
 			raise VoikkoException(u"Could not set boolean option " + str(option) + u" to value " + str(value) + u".")
 	
+	def __isValidInput(self, text):
+		return u"\0" not in text
+	
 	def terminate(self):
 		"""Releases the resources allocated by libvoikko for this instance. The instance cannot be used anymore
 		after this method has been called. The resources are released automatically when the Python object is
@@ -293,7 +304,7 @@ class Voikko(object):
 		lib.voikko_dict_description.argtypes = [c_void_p]
 		lib.voikko_dict_description.restype = c_char_p
 		
-		cDicts = lib.voikko_list_dicts(path)
+		cDicts = lib.voikko_list_dicts(_anyStringToUtf8(path))
 		dicts = []
 		i = 0
 		while bool(cDicts[i]):
@@ -342,6 +353,9 @@ class Voikko(object):
 		"""Check the spelling of given word. Return true if the word is correct,
 		false if it is incorrect.
 		"""
+		if not self.__isValidInput(word):
+			return False
+		
 		result = self.__lib.voikkoSpellUcs4(self.__handle, word)
 		if result == 0:
 			return False
@@ -354,6 +368,8 @@ class Voikko(object):
 		"""Generate a list of suggested spellings for given (misspelled) word.
 		If the given word is correct, the list contains only the word itself.
 		"""
+		if not self.__isValidInput(word):
+			return []
 		
 		cSuggestions = self.__lib.voikkoSuggestUcs4(self.__handle, word)
 		pSuggestions = []
@@ -404,6 +420,9 @@ class Voikko(object):
 		Unlike the C based API this method accepts multiple paragraphs
 		separated by newline characters.
 		"""
+		if not self.__isValidInput(text):
+			return []
+		
 		textUnicode = unicode(text)
 		errorList = []
 		offset = 0
@@ -416,7 +435,7 @@ class Voikko(object):
 		"""Return a human readable explanation for grammar error code in
 		given language.
 		"""
-		explanation = self.__lib.voikko_error_message_cstr(errorCode, language)
+		explanation = self.__lib.voikko_error_message_cstr(_anyStringToUtf8(errorCode), _anyStringToUtf8(language))
 		return unicode(explanation, "UTF-8")
 	
 	def analyze(self, word):
@@ -424,6 +443,9 @@ class Voikko(object):
 		analysis results. The results are represented as maps having property
 		names as keys and property values as values.
 		"""
+		if not self.__isValidInput(word):
+			return []
+		
 		cAnalysisList = self.__lib.voikkoAnalyzeWordUcs4(self.__handle, word)
 		pAnalysisList = []
 		
@@ -449,6 +471,19 @@ class Voikko(object):
 	
 	def tokens(self, text):
 		"""Split the given natural language text into a list of Token objects."""
+		startIndex = 0
+		tokens = []
+		while True:
+			i = text.find(u"\0", startIndex)
+			if i == -1:
+				break
+			tokens = tokens + self.__splitTokens(text[startIndex:i])
+			tokens.append(Token(u"\0", Token.UNKNOWN))
+			startIndex = i + 1
+		tokens = tokens + self.__splitTokens(text[startIndex:])
+		return tokens
+	
+	def __splitTokens(self, text):
 		uniText = unicode(text)
 		result = []
 		textLen = len(uniText)
@@ -467,6 +502,9 @@ class Voikko(object):
 	
 	def sentences(self, text):
 		"""Split the given natural language text into a list of Sentence objects."""
+		if not self.__isValidInput(text):
+			return [Sentence(text, Sentence.NONE)]
+		
 		uniText = unicode(text)
 		result = []
 		textLen = len(uniText)
@@ -491,6 +529,9 @@ class Voikko(object):
 		  '=' = hyphentation point (character at this position
 		        is replaced by the hyphen.)
 		"""
+		if not self.__isValidInput(word):
+			return "".ljust(len(word))
+		
 		cHyphenationPattern = self.__lib.voikkoHyphenateUcs4(self.__handle, word)
 		hyphenationPattern = string_at(cHyphenationPattern)
 		self.__lib.voikkoFreeCstr(cHyphenationPattern)
