@@ -24,6 +24,13 @@
 
 namespace libvoikko { namespace grammar {
 
+/** Possible types for trailing parts of compound verbs */
+enum FollowingVerbType {
+	FOLLOWING_VERB_NONE,
+	FOLLOWING_VERB_A_INFINITIVE,
+	FOLLOWING_VERB_MA_INFINITIVE
+};
+
 /**
  * Grammar checker sentence token.
  */
@@ -41,10 +48,31 @@ class Token {
 		/** True if this word may be (but is not necessarily) the first
 		 *  word in a sentence. */
 		bool possibleSentenceStart;
-
+		
 		/** True if this word may be a geographical name in genitive case. */
 		bool isGeographicalNameInGenitive;
 		
+		/** True if this is a proper noun that might be a geographical name ("Sämpyläjoki") */
+		bool possibleGeographicalName;
+		
+		/** True if this word is a verb negative ("en", "älä" jne.) */
+		bool isVerbNegative;
+		
+		/** True if this word cannot be anything else than a positive verb */
+		bool isPositiveVerb;
+		
+		/**
+		 * What kind of verb must follow this verb in compound verb check. NONE if
+		 * this word is not (or may not be) a verb.
+		 */
+		FollowingVerbType requireFollowingVerb;
+		
+		/**
+		 * What kind of verb this word is if it is used as a trailing part in compound
+		 * verb constructs. NONE if this word is not a verb.
+		 */
+		FollowingVerbType verbFollowerType;
+		
 		/** Null terminated string containing the token text */
 		wchar_t * str;
 		
