@@ -27,7 +27,7 @@ namespace libvoikko { namespace grammar { namespace check {
  */
 class CapitalizationCheck : public ParagraphCheck {
 	public:
-		void check(voikko_options_t * options, const Paragraph * sentence);
+		void check(voikko_options_t * options, const Paragraph * paragraph);
 };
 
 } } }
