@@ -1,5 +1,5 @@
 /* Libvoikko: Finnish spellchecker and hyphenator library
- * Copyright (C) 2006 - 2009 Harri Pitkänen <hatapitk@iki.fi>
+ * Copyright (C) 2006 - 2010 Harri Pitkänen <hatapitk@iki.fi>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,24 +21,27 @@
 #ifndef VOIKKO_PORTING_H
 #define VOIKKO_PORTING_H
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+  #include <config.h>
+#endif
 
 #if defined(WIN32) || defined(_WIN32) || defined(__WIN32__)
 # ifndef WIN32
 #  define WIN32
 # endif
-# define INTERNAL_CHARSET "UCS-2-INTERNAL"
-# include <locale.h>
-# define ENTER_V char*enter_v_origl=setlocale(LC_CTYPE,0);setlocale(LC_CTYPE,"fin");
-# define EXIT_V setlocale(LC_CTYPE,enter_v_origl);
+#endif
+
+#define VOIKKOLINKAGE extern "C"
+
+/* Shared library support */
+#ifdef WIN32
+  #define VOIKKOEXPORT VOIKKOLINKAGE __declspec(dllexport)
 #else
-# define ENTER_V
-# define EXIT_V
-# if defined(__FreeBSD__) || defined(__APPLE__)
-#  define INTERNAL_CHARSET "UCS-4-INTERNAL"
-# else
-#  define INTERNAL_CHARSET "WCHAR_T"
-# endif
+  #ifdef GCC_VISIBILITY
+    #define VOIKKOEXPORT VOIKKOLINKAGE __attribute__ ((visibility("default")))
+  #else
+    #define VOIKKOEXPORT VOIKKOLINKAGE
+  #endif
 #endif
 
 #endif
