@@ -101,7 +101,7 @@ VOIKKOEXPORT int voikkoSpellUcs4(voikko_options_t * voikkoOptions, const wchar_t
 		return VOIKKO_SPELL_OK;
 	}
 	if (nchars > LIBVOIKKO_MAX_WORD_CHARS) {
-		return VOIKKO_INTERNAL_ERROR;
+		return VOIKKO_SPELL_FAILED;
 	}
 	
 	wchar_t * nword = voikko_normalise(word, nchars);
@@ -214,6 +214,7 @@ VOIKKOEXPORT int voikkoSpellUcs4(voikko_options_t * voikkoOptions, const wchar_t
 			case CT_ALL_UPPER:
 				sres = voikko_cached_spell(voikkoOptions, buffer, nchars);
 				result = (sres == SPELL_FAILED) ? VOIKKO_SPELL_FAILED : VOIKKO_SPELL_OK;
+				break;
 			default: /* should not happen */
 				result = VOIKKO_INTERNAL_ERROR;
 		}
@@ -229,7 +230,7 @@ VOIKKOEXPORT int voikkoSpellCstr(voikko_options_t * handle, const char * word) {
 	}
 	size_t len = strlen(word);
 	if (len > LIBVOIKKO_MAX_WORD_CHARS) {
-		return 0;
+		return VOIKKO_SPELL_FAILED;
 	}
 	wchar_t * word_ucs4 = utils::StringUtils::ucs4FromUtf8(word, len);
 	if (word_ucs4 == 0) {
